##  Cell Behavior and Visual Indicators
In the edit mode, the color and icons of the cells indicate their status. These visual cues help you quickly identify which fields you can modify and which are restricted.
Status | Appearance | Example
---|---|---
Editable | White background | ![Editable cell with white background](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9f827cb5df4a457d83714616fc565ad6_LowRes.png)
Read-only | Light gray background with lock icon | ![Read-only cell with light gray background and lock icon](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3ec08d60a80c492589b2549ddd7f46a2_LowRes.png)
Unsaved changes | Light yellow background | ![Cell with unsaved changes, light yellow background](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio5662184b91434e8aa66d077e2a9de414_LowRes.png)
Incorrect input | Red background with warning icon | ![Cell with incorrect input, red background and warning icon](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio14871ee9e94e47188e4e0d40e27ab9f1_LowRes.png)


